@@ -199,8 +199,8 @@ class DateSpan(object):
         This is used for couch queries to get the adjusted date as a string
         that can be easily used in a couch view.
         """
-        if self.startdate:
-            return self.startdate.strftime(self.format)
+        # todo: should we get rid of this?
+        return self.startdate_display
 
     @property
     def startdate_utc(self):
@@ -282,9 +282,10 @@ class DateSpan(object):
     def get_validation_reason(self):
         if self.startdate is None or self.enddate is None:
             return "You have to specify both dates!"
-        else:
-            if self.enddate < self.startdate:
-                return "You can't have an end date of %s after start date of %s" % (self.enddate, self.startdate)
+        elif self.enddate < self.startdate:
+            return "You can't have an end date of %s after start date of %s" % (self.enddate, self.startdate)
+        elif self.startdate < datetime.datetime(1900, 01, 01) or self.enddate < datetime.datetime(1900, 01, 01):
+            return "You can't use dates earlier than the year 1900"
         return ""
     
     def __str__(self):
@@ -299,8 +300,14 @@ class DateSpan(object):
         if today_or_tomorrow(self.enddate, self.inclusive):
             return "last %s days" % ((self.enddate - self.startdate).days + (1 if self.inclusive else 0))
         
-        return "%s to %s" % (self.startdate.strftime(self.format), 
-                             self.enddate.strftime(self.format))
+        return self.default_serialization()
+
+    def __repr__(self):
+        return str(self)
+
+    def default_serialization(self):
+        return "%s to %s" % (self.startdate_display,
+                             self.enddate_display)
 
     @classmethod
     def since(cls, days, enddate=None, format=DEFAULT_DATE_FORMAT, inclusive=True, timezone=pytz.utc):
@@ -330,6 +337,26 @@ class DateSpan(object):
         return DateSpan(start, end, format, inclusive, timezone)
 
 
+    @classmethod
+    def from_month(cls, month=None, year=None, format=DEFAULT_DATE_FORMAT,
+        inclusive=True, timezone=pytz.utc):
+        """
+        Generate a DateSpan object given a numerical month and year.
+        Both are optional and default to the current month/year.
+
+            april = DateSpan.from_month(04, 2013)
+        """
+        if month is None:
+            month = datetime.date.today().month
+        if year is None:
+            year = datetime.date.today().year
+        assert isinstance(month, int) and isinstance(year, int)
+        start = datetime.datetime(year, month, 1)
+        next = start + datetime.timedelta(days=32)
+        end = datetime.datetime(next.year, next.month, 1) - datetime.timedelta(days=1)
+        return DateSpan(start, end, format, inclusive, timezone)
+
+
     def parse(self, startdate_str, enddate_str, parse_format, display_format=None):
         """
         Generate a DateSpan with string formats. 
